@@ -27,12 +27,18 @@ signer = leselys.core.signer
 # API
 #######################################################################
 
+# Get feeds info
+@app.route('/api/get_feeds')
+def get_feeds():
+    return jsonify(success=True, content=reader.get_feeds())
+
+
 # Set password
 @app.route('/api/set_password', methods=['POST'])
 def set_password():
     # For demo
     heroku_urls = [
-            "http://leselys.herokuapp.com/api/set_password", 
+            "http://leselys.herokuapp.com/api/set_password",
             "https://leselys.herokuapp.com/api/set_password",
             "http://leselys.herokuapp.com:80/api/set_password",
             "https://leselys.herokuapp.com:443/api/set_password"]
@@ -90,6 +96,7 @@ def remove(feed_id):
 # Return list of entries for given feed_id
 @app.route('/api/get/<feed_id>')
 @login_required
+@cached(30)
 def get(feed_id):
     start = int(request.args.get('start', 0))
     stop = int(request.args.get('stop', 50))
@@ -181,8 +188,8 @@ def login():
                 rsp = make_response(jsonify(success=True, output="Successfully logged in."))
             if remember:
                 session.permanent = True
-                rsp.set_cookie('remember', True)
-                rsp.set_cookie('token', signer.sign(password))
+                rsp.set_cookie('remember', "true")
+                rsp.set_cookie('token', ''.join(str(signer.sign(storage.get_password())).split('.')[1:]))
             return rsp
     else:
         if request.args.get('jsonify', "true") == "false":
@@ -200,8 +207,8 @@ def logout():
         rsp = make_response(redirect(url_for('login_view')))
     else:
         rsp = make_response(jsonify(success=True, output="Successfully logged out."))
-    rsp.set_cookie('token', None)
-    rsp.set_cookie('remember', False)
+    rsp.set_cookie('token', "true")
+    rsp.set_cookie('remember', "false")
     return rsp
 
 
@@ -210,7 +217,7 @@ def logout():
 @login_required
 def set_theme():
     theme_name = request.form['theme'].lower()
-    _themes = dict((k.lower(), v) for k, v in themes.iteritems())
+    _themes = dict((k.lower(), v) for k, v in themes.items())
     if not theme_name in _themes.keys():
         return jsonify(success=False, output='Theme not exists')
 
