@@ -1,7 +1,11 @@
 # coding: utf-8
 import os
 import sys
-import ConfigParser
+
+try:
+    import configparser
+except ImportError:
+    import ConfigParser as configparser
 
 import leselys
 import werkzeug
@@ -16,6 +20,39 @@ from werkzeug.contrib.cache import SimpleCache
 from leselys.backends.storage import _load_storage
 from leselys.backends.session import _load_session
 
+# from http://flask.pocoo.org/snippets/35/
+class ReverseProxied(object):
+    '''Wrap the application in this middleware and configure the
+    front-end server to add these headers, to let you quietly bind
+    this to a URL other than / and to an HTTP scheme that is
+    different than what is used locally.
+
+    In nginx:
+    location /myprefix {
+        proxy_pass http://192.168.0.1:5001;
+        proxy_set_header Host $host;
+        proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+        proxy_set_header X-Scheme $scheme;
+        proxy_set_header X-Script-Name /myprefix;
+        }
+
+    :param app: the WSGI application
+    '''
+    def __init__(self, app):
+        self.app = app
+
+    def __call__(self, environ, start_response):
+        script_name = environ.get('HTTP_X_SCRIPT_NAME', '')
+        if script_name:
+            environ['SCRIPT_NAME'] = script_name
+            path_info = environ['PATH_INFO']
+            if path_info.startswith(script_name):
+                environ['PATH_INFO'] = path_info[len(script_name):]
+
+        scheme = environ.get('HTTP_X_SCHEME', '')
+        if scheme:
+            environ['wsgi.url_scheme'] = scheme
+        return self.app(environ, start_response)
 
 class Core(object):
     def __init__(self):
@@ -30,6 +67,7 @@ class Core(object):
         self.app = Flask(__name__)
         self.app.config['SECRET_KEY'] = os.urandom(24)
         self.app.config['SEND_FILE_MAX_AGE_DEFAULT'] = 31536000
+        self.app.wsgi_app = ReverseProxied(self.app.wsgi_app)
 
         py_v = sys.version_info
         py_v = "%s.%s.%s" % (py_v[0], py_v[1], py_v[2])
@@ -49,7 +87,7 @@ class Core(object):
             sys.exit(1)
         self.args = args
         self.config_path = config_path
-        self.config = ConfigParser.ConfigParser()
+        self.config = configparser.ConfigParser()
         self.config.read(self.config_path)
 
         if self.config.has_section('webserver') and self.config.get('webserver', 'host'):
