@@ -1,5 +1,8 @@
 # coding: utf-8
-from HTMLParser import HTMLParser
+try:
+    from HTMLParser import HTMLParser
+except ImportError:
+    from html.parser import HTMLParser
 
 
 class FeedFinder(HTMLParser):
