@@ -71,13 +71,13 @@ def login_required(f):
         # Not in cache
         if not session.get('logged_in'):
             # No cookie
-            if not request.cookies.get('remember'):
+            if request.cookies.get('remember') == "false":
                 if request.args.get('jsonify', "false") == "false":
                     return redirect(url_for('login_view'))
                 else:
                     return jsonify(success=False, output="Failed to log in.")
             else:
-                password_md5 = request.cookies.get('password')
+                password_md5 = "%s.%s" % (storage.get_password(), request.cookies.get('token'))
                 try:
                     password_unsigned = signer.unsign(
                         password_md5, max_age=15 * 24 * 60 * 60)
