@@ -6,8 +6,12 @@ import leselys
 import copy
 import requests
 
-from urlparse import urlparse
-from urlparse import urljoin
+try:
+    from urlparse import urlparse
+    from urlparse import urljoin
+except ImportError:
+    from urllib.parse import urlparse
+    from urllib.parse import urljoin
 
 from leselys.helpers import u
 from leselys.helpers import get_datetime
@@ -36,7 +40,8 @@ for element in acceptable_elements:
 
 
 class Retriever(threading.Thread):
-    """The Retriever object has to retrieve all feeds asynchronously and
+    """
+    The Retriever object has to retrieve all feeds asynchronously and
     return it to the Reader when a new subscription arrives
     """
 
@@ -95,7 +100,8 @@ class Retriever(threading.Thread):
 
 
 class Refresher(threading.Thread):
-    """The Refresher object have to retrieve all new entries asynchronously
+    """
+    The Refresher object have to retrieve all new entries asynchronously
     """
 
     def __init__(self, feed):
@@ -106,11 +112,23 @@ class Refresher(threading.Thread):
 
     def run(self):
         self.data = feedparser.parse(self.feed.get('url'))
+        if self.data.get('bozo_exception', False):
+            print("!! Can't retrieve %s feed (%s)" % (self.feed_title.encode('utf-8'), self.data['bozo_exception']))
+            return
 
+        need_update = False
         # Update title if it change
         if self.data.feed.get('title') != self.feed_title:
             self.feed['title'] = self.data.feed.get('title')
             self.feed_title = self.feed['title']
+            need_update = True
+        # Add website url if not setted
+        if self.data.feed.get('link') != self.feed.get('link'):
+            self.feed['link'] = self.data.feed.get('link')
+            self.feed_link = self.feed['link']
+            need_update = True
+
+        if need_update:
             storage.update_feed(self.feed_id, copy.copy(self.feed))
 
         local_update = self.feed.get('last_update')
@@ -158,7 +176,7 @@ class Refresher(threading.Thread):
             for entry_guid in readed:
                 entry = storage.get_story_by_guid(self.feed_id, entry_guid)
                 if entry:
-                    print(' _ update: %s' % entry['title'].encode('utf-8'))
+                    # print(' _ update: %s' % entry['title'].encode('utf-8'))
                     entry['read'] = True
                     storage.update_story(entry['_id'], copy.copy(entry))
 
@@ -217,6 +235,7 @@ class Reader(object):
             return {'success': False, 'output': 'Bad feed'}
 
         title = feed.feed['title']
+        link = feed.feed['link']
         feed_id = storage.get_feed_by_title(title)
         if not feed_id:
             if feed.feed.get('updated_parsed'):
@@ -232,6 +251,7 @@ class Reader(object):
 
             feed_id = storage.add_feed({'url': url,
                                         'title': title,
+                                        'link': link,
                                         'last_update': feed_update})
         else:
             return {'success': False, 'output': 'Feed already exists'}
@@ -243,6 +263,7 @@ class Reader(object):
             'success': True,
             'title': title,
             'url': url,
+            'link': link,
             'feed_id': feed_id,
             'output': 'Feed added',
             'counter': len(feed['entries'])}
@@ -253,7 +274,7 @@ class Reader(object):
         storage.remove_feed(feed_id)
         return {"success": True, "output": "Feed removed"}
 
-    def get(self, feed_id=False, feed_type="combined-ffed", order_type="user", start=0, stop=50):
+    def get(self, feed_id=False, feed_type="combined-feed", order_type="user", start=0, stop=50):
         # Special feeds
         if not feed_id:
             if feed_type == "combined-feed":
@@ -328,10 +349,12 @@ class Reader(object):
             feeds.append({'title': feed.get('title'),
                           'id': feed_id,
                           'url': feed.get('url'),
+                          'link': feed.get('link', feed.get('url')),
                           'counter': self.get_unread(feed['_id']),
                           'ordering': ordering
                           })
-        return feeds
+        return sorted(feeds, key=lambda k: k['title'].lower())
+        #return feeds
 
     def refresh(self, feed_id):
         feed = storage.get_feed_by_id(feed_id)
