@@ -30,7 +30,7 @@ def get_feeds():
 
 @app.context_processor
 def get_theme():
-    _themes = dict((k.lower(), v) for k, v in themes.iteritems())
+    _themes = dict((k.lower(), v) for k, v in themes.items())
     theme = session.get('theme_name')
     if not theme:
         theme = storage.get_setting('theme_name')
